@@ -1273,6 +1273,19 @@ Rcpp::List SimSSMLinSDEIVary2(
   return output;
 }
 // -----------------------------------------------------------------------------
+// edit .setup/cpp/simStateSpace-solve-syl-dot.cpp
+// Ivan Jacob Agaloos Pesigan
+// -----------------------------------------------------------------------------
+
+#include <RcppArmadillo.h>
+// [[Rcpp::depends(RcppArmadillo)]]
+// [[Rcpp::export(.SolveSyl)]]
+arma::mat SolveSyl(arma::mat A, arma::mat B, arma::mat C) {
+  arma::mat X;
+  arma::syl(X, A, B, C);
+  return X;
+}
+// -----------------------------------------------------------------------------
 // edit .setup/cpp/simStateSpace-test-phi.cpp
 // Ivan Jacob Agaloos Pesigan
 // -----------------------------------------------------------------------------
